@@ -387,7 +387,10 @@ def parse_string(
                 if isinstance(var_value, Text) or isinstance(var_value, int):
                     var_value = var_value
                 else:
-                    var_value = var_value[suffix]
+                    if var_value is not None:
+                        var_value = var_value[suffix]
+                    else:
+                        return var_value
                 full_string = remove_bracket_first(raw_string)
                 raw_string = full_string
 
@@ -435,7 +438,7 @@ def parse_data(
 
         if get_statement_type(var_value) == "sql":
             try:
-                if "&&db:" in var_value:
+                if "&&db:" in var_value:  # 指定环境执行sql
                     value = execute_sql(var_value.split("&&db:")[1], var_value.split("&&db:")[0])
                 else:
                     value = execute_sql(variables_mapping["mysql"], var_value)
@@ -543,8 +546,11 @@ def parse_variables_mapping(
 
             try:
                 parsed_value = parse_data(
-                    var_value, parsed_variables, functions_mapping
+                    var_value, variables_mapping, functions_mapping
                 )
+                # parsed_value = parse_data(
+                #     var_value, parsed_variables, functions_mapping
+                # )
             except exceptions.VariableNotFound:
                 continue
 
