@@ -143,7 +143,7 @@ class HttpRunner(object):
             if attr in step.variables:
                 has_attr = True
                 break
-
+        extract_mapping = {}
         if aspect == "setup":
             if not has_attr:
                 for attr in not_need_configured_attr:  # 判断是否有数据源
@@ -156,9 +156,16 @@ class HttpRunner(object):
                 if step.setup:
                     logger.info("setup begin execute >>>>>>")
                     for s in step.setup:
-                        parse_data(
-                            s, variables_mapping, functions_mapping
-                        )
+                        if "##" in s:
+                            extract_mapping[s.split("##")[1]] = parse_data(s.split("##")[0], variables_mapping,
+                                                                           functions_mapping)
+                            variables_mapping.update(extract_mapping)
+                            logger.info(f"extract mapping: {extract_mapping}")
+                        else:
+                            parse_data(
+                                s, variables_mapping, functions_mapping
+                            )
+
         elif aspect == "teardown":
             if not has_attr:
                 for attr in not_need_configured_attr:  # 判断是否有数据源
@@ -171,9 +178,15 @@ class HttpRunner(object):
                 if step.teardown:
                     logger.info("teardown begin execute >>>>>>")
                     for s in step.teardown:
-                        parse_data(
-                            s, variables_mapping, functions_mapping
-                        )
+                        if "##" in s:
+                            extract_mapping[s.split("##")[1]] = parse_data(s.split("##")[0], variables_mapping,
+                                                                           functions_mapping)
+                            variables_mapping.update(extract_mapping)
+                            logger.info(f"extract mapping: {extract_mapping}")
+                        else:
+                            parse_data(
+                                s, variables_mapping, functions_mapping
+                            )
 
     def __run_step_request(self, step: TStep) -> StepData:
         """run teststep: request"""
@@ -188,6 +201,10 @@ class HttpRunner(object):
         if step.setup_hooks:
             self.__call_hooks(step.setup_hooks, step.variables, "setup request")
 
+        # execute setup
+        if step.setup:
+            self.__execute("setup", step, step.variables, self.__project_meta.functions)
+
         parsed_request_dict = parse_data(
             request_dict, step.variables, self.__project_meta.functions
         )
@@ -197,12 +214,6 @@ class HttpRunner(object):
         )
         step.variables["request"] = parsed_request_dict
 
-        variables_mapping = step.variables
-        # variables_mapping.update(extract_mapping)
-        # execute setup
-        if step.setup:
-            self.__execute("setup", step, variables_mapping, self.__project_meta.functions)
-
         # prepare arguments
         method = parsed_request_dict.pop("method")
         url_path = parsed_request_dict.pop("url")
@@ -243,7 +254,7 @@ class HttpRunner(object):
 
         # extract
         extractors = step.extract
-        extract_mapping = resp_obj.extract(extractors, variables_mapping, self.__project_meta.functions)
+        extract_mapping = resp_obj.extract(extractors, step.variables, self.__project_meta.functions)
         step_data.export_vars = extract_mapping
 
         variables_mapping = step.variables
@@ -357,6 +368,7 @@ class HttpRunner(object):
 
     def __parse_config(self, config: TConfig) -> NoReturn:
         config.variables.update(self.__session_variables)
+        config.variables.update(config.datasource)
         config.variables = parse_variables_mapping(
             config.variables, self.__project_meta.functions
         )
