@@ -1,6 +1,8 @@
 import inspect
 from typing import Text, Any, Union, Callable, Dict
 
+from deepdiff import DeepDiff
+
 from rrtv_httprunner.models import (
     TConfig,
     TStep,
@@ -329,6 +331,19 @@ class StepRequestValidation(object):
         )
         return self
 
+    def assert_diff(self, check_value: Union[Dict, Text], expected_value: Union[Dict, Text], message: Text = "",
+                    **kwargs) -> "StepRequestValidation":
+        """
+        Verifies two objects are consistent
+
+        Usage:
+            >>> DeepDiff(check_value, expected_value, **kwargs)
+        """
+        self.__step_context.validators.append(
+            {"t1": check_value, "t2": expected_value, "kwargs": kwargs, "message": message}
+        )
+        return self
+
     def perform(self) -> TStep:
         return self.__step_context
 
@@ -525,7 +540,7 @@ class RunRequest(object):
         self.__step_context.setup.append(command)
         return self
 
-    def setup_sql(self, sql: Text) -> "RunRequest":
+    def setup_sql(self, sql: Text, assign_var_name: Text = None) -> "RunRequest":
         """ 在接口执行之前执行SQL
 
         Args:
@@ -535,7 +550,10 @@ class RunRequest(object):
             >>> RunRequest.setup_sql("select * from mysql")
 
         """
-        self.__step_context.setup.append("sql:" + sql)
+        if assign_var_name is not None:
+            self.__step_context.setup.append("sql:" + sql + "##" + assign_var_name)
+        else:
+            self.__step_context.setup.append("sql:" + sql)
         return self
 
     def setup_redis(self, redis: Text) -> "RunRequest":
